@@ -20,6 +20,7 @@ from tempest.lib import decorators
 from testtools import testcase as tc
 
 from manila_tempest_tests.common import constants
+from manila_tempest_tests.common import waiters
 from manila_tempest_tests.tests.api import base
 from manila_tempest_tests import utils
 
@@ -40,17 +41,14 @@ class ManageNFSShareTest(base.BaseSharesAdminTest):
         super(ManageNFSShareTest, cls).skip_checks()
         if not CONF.share.run_manage_unmanage_tests:
             raise cls.skipException('Manage/unmanage tests are disabled.')
-
-    @classmethod
-    def resource_setup(cls):
         if cls.protocol not in CONF.share.enable_protocols:
             message = "%s tests are disabled" % cls.protocol
             raise cls.skipException(message)
-
         utils.skip_if_manage_not_supported_for_version()
 
+    @classmethod
+    def resource_setup(cls):
         super(ManageNFSShareTest, cls).resource_setup()
-
         # Create share type
         cls.st_name = data_utils.rand_name("manage-st-name")
         cls.extra_specs = {
@@ -81,7 +79,8 @@ class ManageNFSShareTest(base.BaseSharesAdminTest):
             # After 'unmanage' operation, share instance should be deleted.
             # Assert not related to 'manage' test, but placed here for
             # resource optimization.
-            share_instance_list = self.shares_v2_client.list_share_instances()
+            share_instance_list = self.shares_v2_client.list_share_instances(
+                )['share_instances']
             share_ids = [si['share_id'] for si in share_instance_list]
             self.assertNotIn(share['id'], share_ids)
 
@@ -94,7 +93,7 @@ class ManageNFSShareTest(base.BaseSharesAdminTest):
             'service_host': share['host'],
             'export_path': export_path,
             'protocol': share['share_proto'],
-            'share_type_id': self.st['share_type']['id'],
+            'share_type_id': self.st['id'],
             'name': name,
             'description': description,
             'is_public': is_public,
@@ -102,7 +101,8 @@ class ManageNFSShareTest(base.BaseSharesAdminTest):
         }
         if CONF.share.multitenancy_enabled:
             manage_params['share_server_id'] = share['share_server_id']
-        managed_share = self.shares_v2_client.manage_share(**manage_params)
+        managed_share = self.shares_v2_client.manage_share(
+            **manage_params)['share']
 
         # Add managed share to cleanup queue
         self.method_resources.insert(
@@ -110,8 +110,9 @@ class ManageNFSShareTest(base.BaseSharesAdminTest):
                 'client': self.shares_client})
 
         # Wait for success
-        self.shares_v2_client.wait_for_share_status(managed_share['id'],
-                                                    constants.STATUS_AVAILABLE)
+        waiters.wait_for_resource_status(self.shares_v2_client,
+                                         managed_share['id'],
+                                         constants.STATUS_AVAILABLE)
 
         # Verify data of managed share
         self.assertEqual(name, managed_share['name'])
@@ -120,10 +121,10 @@ class ManageNFSShareTest(base.BaseSharesAdminTest):
         self.assertEqual(share['share_proto'], managed_share['share_proto'])
 
         if utils.is_microversion_ge(version, "2.6"):
-            self.assertEqual(self.st['share_type']['id'],
+            self.assertEqual(self.st['id'],
                              managed_share['share_type'])
         else:
-            self.assertEqual(self.st['share_type']['name'],
+            self.assertEqual(self.st['name'],
                              managed_share['share_type'])
 
         if utils.is_microversion_ge(version, "2.8"):
@@ -149,19 +150,19 @@ class ManageNFSShareTest(base.BaseSharesAdminTest):
 
     @decorators.idempotent_id('15b654d0-34ed-4154-9f5f-b96d2e4e9d1c')
     @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
-    @base.skip_if_microversion_not_supported("2.5")
+    @utils.skip_if_microversion_not_supported("2.5")
     def test_manage_with_os_share_manage_url(self):
         self._test_manage(version="2.5")
 
     @decorators.idempotent_id('8c0beefb-19da-441e-b73f-d90eb8000ff3')
     @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
-    @base.skip_if_microversion_not_supported("2.8")
+    @utils.skip_if_microversion_not_supported("2.8")
     def test_manage_with_is_public_True(self):
         self._test_manage(is_public=True, version="2.8")
 
     @decorators.idempotent_id('da7b7a4f-6693-4460-bdb7-1f8d42032bc6')
     @tc.attr(base.TAG_POSITIVE, base.TAG_API_WITH_BACKEND)
-    @base.skip_if_microversion_not_supported("2.16")
+    @utils.skip_if_microversion_not_supported("2.16")
     def test_manage_show_user_id(self):
         self._test_manage(version="2.16")
 
